tdub.rex
--------

A module for handling TRExFitter workspaces

.. currentmodule:: tdub.rex

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   available_regions
   chisq
   chisq_text
   data_histogram
   meta_axis_label
   meta_text
   plot_all_regions
   prefit_total_and_uncertainty
   prefit_histogram
   prefit_histograms
   postfit_available
   postfit_total_and_uncertainty
   postfit_histogram
   postfit_histograms
   stack_canvas

Reference
^^^^^^^^^

.. autofunction:: available_regions
.. autofunction:: chisq
.. autofunction:: chisq_text
.. autofunction:: data_histogram
.. autofunction:: plot_all_regions
.. autofunction:: meta_axis_label
.. autofunction:: meta_text
.. autofunction:: prefit_total_and_uncertainty
.. autofunction:: prefit_histogram
.. autofunction:: prefit_histograms
.. autofunction:: postfit_available
.. autofunction:: postfit_total_and_uncertainty
.. autofunction:: postfit_histogram
.. autofunction:: postfit_histograms
.. autofunction:: stack_canvas
